@@ -11,7 +11,6 @@ from textual.coordinate import Coordinate
 from textual.geometry import Offset
 from textual.message import Message
 from textual.widgets import DataTable
-from textual.widgets._data_table import _DEFAULT_CELL_X_PADDING
 from textual.widgets.data_table import (
     CellDoesNotExist,
     CellKey,
@@ -26,6 +25,9 @@ from textual.widgets.data_table import (
 ROWS = [["0/0", "0/1"], ["1/0", "1/1"], ["2/0", "2/1"]]
 
 
+_DEFAULT_CELL_X_PADDING = 1
+
+
 class DataTableApp(App):
     messages_to_record = {
         "CellHighlighted",
@@ -192,12 +194,12 @@ async def test_cursor_movement_with_home_pagedown_etc(show_header):
         await pilot.pause()
         assert table.cursor_coordinate == Coordinate(0, 1)
 
-        await pilot.press("end")
-        await pilot.pause()
-        assert table.cursor_coordinate == Coordinate(2, 1)
-
         await pilot.press("home")
         await pilot.pause()
+        assert table.cursor_coordinate == Coordinate(0, 0)
+
+        await pilot.press("end")
+        await pilot.pause()
         assert table.cursor_coordinate == Coordinate(0, 1)
 
 
@@ -255,6 +257,16 @@ async def test_add_row_duplicate_key():
             table.add_row("2", key="1")  # Duplicate row key
 
 
+async def test_add_row_too_many_values():
+    app = DataTableApp()
+    async with app.run_test():
+        table = app.query_one(DataTable)
+        table.add_column("A")
+        table.add_row("1", key="1")
+        with pytest.raises(ValueError):
+            table.add_row("1", "2")
+
+
 async def test_add_column_duplicate_key():
     app = DataTableApp()
     async with app.run_test():
@@ -287,6 +299,25 @@ async def test_add_columns():
         assert len(table.columns) == 3
 
 
+async def test_add_columns_with_tuples():
+    app = DataTableApp()
+    async with app.run_test():
+        table = app.query_one(DataTable)
+        column_keys = table.add_columns(
+            ("Column 1", "col1"), "Column 2", ("Column 3", "col3")
+        )
+        assert len(column_keys) == 3
+        assert len(table.columns) == 3
+
+        assert column_keys[0] == "col1"
+        assert column_keys[1] != "col1"
+        assert column_keys[2] == "col3"
+
+        assert table.columns[column_keys[0]].label.plain == "Column 1"
+        assert table.columns[column_keys[1]].label.plain == "Column 2"
+        assert table.columns[column_keys[2]].label.plain == "Column 3"
+
+
 async def test_add_columns_user_defined_keys():
     app = DataTableApp()
     async with app.run_test():
